@@ -18,11 +18,6 @@ LOG = core.get_logger("logs")
 CLUSTERS = core.config.get("clusters")
 
 
-def escape_ansi(line):
-    ansi_escape = re.compile(r"(\x9B|\x1B\[)[0-?]*[ -/]*[@-~]")
-    return ansi_escape.sub("", str(line))
-
-
 def get_logs_files_names():
     log_directory = core.config.get("directories/logs")
     files = glob.glob(log_directory + os.sep + "*.log")
@@ -71,7 +66,6 @@ def get_logs_content(
         if content:
             with open(file_path, "r") as f:
                 log_content = f.read()
-        # log_content = escape_ansi(log_content)
 
         file_size = os.path.getsize(file_path)
         name = name.replace(".log", "")
