@@ -1,4 +1,5 @@
-import sys, imp, inspect, os, glob, copy
+import sys, imp, inspect, os, glob, re
+import typing
 
 from ..models.watcher import ModuleWatcher
 from typing import List, Dict, OrderedDict
@@ -6,7 +7,7 @@ from typing import List, Dict, OrderedDict
 myself = lambda: inspect.stack()[1][3]
 
 
-def get_modules_infos(name: str = None, url: str = None):
+def get_modules_infos(name: str = None, url: str = None, mode:str=None):
     from importlib_metadata import version
     import pkgutil
 
@@ -14,6 +15,8 @@ def get_modules_infos(name: str = None, url: str = None):
     for item in pkgutil.iter_modules():
         if name is not None and name.lower() != item.name.lower():
             continue
+        if item.module_finder.path.endswith('.'):
+            continue
         try:
             data[item.name] = version(item.name)
         except:
@@ -76,6 +79,8 @@ def get_modules_infos(name: str = None, url: str = None):
         for key, items in updates.items():
             out[key] = " ".join(items)
         return out
+    if mode == "requirements":
+        return '\n'.join([f"{x}=={y}"for x,y in data.items()])
     return data
 
 
@@ -190,12 +195,14 @@ def filter_kwargs(fct, args: list = [], kwargs: dict = {}) -> dict:
     kwargs = {x: y for x, y in kwargs.items() if x in fargs.args}
     return kwargs
 
+
 def get_subtype(parent_type):
     if hasattr(parent_type, "__args__"):
         if isinstance(parent_type.__args__[0], type):
             return parent_type.__args__[0]
     return None
 
+
 def is_subtype(sub_type, parent_type):
     # TODO: fix
     """if not isinstance(sub_type,type):
@@ -236,7 +243,9 @@ def sort_by_key(input_dict):
     return OrderedDict(sorted(input_dict.items(), key=lambda x: x[0]))
 
 
-def compare_dicts(dict_obj_1, dict_obj_2, sub_elements: dict = None):
+def compare_dicts(
+    dict_obj_1, dict_obj_2, sub_elements: dict = None, ignore: List[str] = None
+):
     if not sub_elements:
         sub_elements = {}
 
@@ -251,11 +260,12 @@ def compare_dicts(dict_obj_1, dict_obj_2, sub_elements: dict = None):
     diffs = []
 
     for key in list_keys:
+        if ignore is not None and any([re.match(i, key) for i in ignore]):
+            continue
         value_1, value_2 = (
-            dict_obj_1[key] if key in dict_obj_1 else None
-        ) if dict_obj_1 is not None else None, (
-            dict_obj_2[key] if key in dict_obj_2 else None
-        ) if dict_obj_2 is not None else None
+            dict_obj_1.get(key, None) if dict_obj_1 is not None else None,
+            dict_obj_2.get(key, None) if dict_obj_2 is not None else None,
+        )
         ref_element = value_1 if value_1 is not None else value_2
 
         if key in sub_elements and value_1 is None and value_2 is None:
@@ -265,7 +275,8 @@ def compare_dicts(dict_obj_1, dict_obj_2, sub_elements: dict = None):
             level_dict[key] = compare_dicts(
                 value_1,
                 value_2,
-                {} if not key in sub_elements else sub_elements[key]["sub_elements"],
+                sub_elements.get(key, {}).get("sub_elements", None),
+                sub_elements.get(key, {}).get("ignore", None),
             )
             diff = level_dict[key]["diff"]
             diffs.append(diff)
@@ -280,8 +291,16 @@ def compare_dicts(dict_obj_1, dict_obj_2, sub_elements: dict = None):
                 if value_2 is not None
                 else None
             )
-            sub_elements_1 = sub_elements_1 or {x: None for x in sub_elements_2.keys()}
-            sub_elements_2 = sub_elements_2 or {x: None for x in sub_elements_1.keys()}
+            sub_elements_1 = (
+                sub_elements_1
+                if sub_elements_1 is not None
+                else {x: None for x in sub_elements_2.keys()}
+            )
+            sub_elements_2 = (
+                sub_elements_2
+                if sub_elements_2 is not None
+                else {x: None for x in sub_elements_1.keys()}
+            )
             list_keys = list(
                 set(sub_elements_1.keys()).union(set(sub_elements_2.keys()))
             )
@@ -289,9 +308,10 @@ def compare_dicts(dict_obj_1, dict_obj_2, sub_elements: dict = None):
             dict_list = {}
             for list_key in list_keys:
                 dict_list[list_key] = compare_dicts(
-                    sub_elements_1[list_key] if list_key in sub_elements_1 else None,
-                    sub_elements_2[list_key] if list_key in sub_elements_2 else None,
+                    sub_elements_1.get(list_key, None),
+                    sub_elements_2.get(list_key, None),
                     sub_elements[key]["sub_elements"],
+                    ignore=sub_elements.get(key, {}).get("ignore", None),
                 )
 
             if "key_type" in sub_elements[key]:
@@ -303,9 +323,9 @@ def compare_dicts(dict_obj_1, dict_obj_2, sub_elements: dict = None):
             diff = any(x["diff"] for x in dict_list.values())
             diffs.append(diff)
         else:
-            diff = (value_1 is None or value_2 is None) or (
-                value_1 != value_2 or key not in dict_obj_1 or key not in dict_obj_2
-            )
+            diff = True
+            if (value_1 is None and value_2 is None) or (value_1 == value_2):
+                diff = False
             level_dict[key] = {"values": [value_1, value_2], "diff": diff}
             diffs.append(diff)
 
@@ -314,6 +334,19 @@ def compare_dicts(dict_obj_1, dict_obj_2, sub_elements: dict = None):
     level_dict["diff"] = any(diffs)
     return level_dict
 
-def get_sub_lists(a_list:list, lenght:int):
+
+def get_sub_lists(a_list: list, lenght: int):
     a_list = list(a_list)
-    return [a_list[i:i+lenght] for i in range(0, len(a_list), lenght)]
\ No newline at end of file
+    return [a_list[i : i + lenght] for i in range(0, len(a_list), lenght)]
+
+
+def is_iterable(o):
+    try:
+        iter(o)
+        return True
+    except:
+        return False
+
+
+def is_list(o):
+    return type(o) == list or is_subtype(type(o), typing.List) or type(o) == tuple
