@@ -267,3 +267,8 @@ def to_list(o):
             el = el[:-2] + "'"
         output.append(el)
     return output
+
+
+def escape_ansi(line):
+    ansi_escape = re.compile(r"(\x9B|\x1B\[)[0-?]*[ -/]*[@-~]")
+    return ansi_escape.sub("", str(line))
