@@ -1,4 +1,4 @@
-from alphaz.models.database.users_definitions import Permission
+from alphaz.models.database.users_definitions import Permission, Role
 from core import core
 from typing import List
 
@@ -15,28 +15,37 @@ def get_permissions(
     direction: str,
     columns: List[str] = None,
 ):
-    return DB.select(
+    permissions = DB.select(
         Permission,
         filters=[Permission.key.like(name)],
-        disabled_relationships=[Permission.role_permissions],
         page=page_index,
         per_page=page_size,
         order_by_direction=direction,
         order_by=order_by,
         columns=columns,
+        disabled_relationships={Permission.roles: [Role.permissions, Role.application]},
     )
+    return permissions
 
-def get_permissions_names(name:str):
+
+def get_permissions_names(name: str):
     return DB.select(
         Permission,
-        optional_filters={Permission.key:{'like':name}},
+        optional_filters={Permission.key: {"like": name}},
         unique=Permission.key,
         distinct=Permission.key,
-        order_by=Permission.key.asc()
+        order_by=Permission.key.asc(),
     )
 
+
 def get_permission(name: str):
-    return DB.select(Permission, filters=[Permission.key == name], first=True)
+    permission = DB.select(
+        Permission,
+        filters=[Permission.key == name],
+        first=True,
+        disabled_relationships={Permission.roles: [Role.permissions, Role.application]},
+    )
+    return permission
 
 
 def create_permission(permission: Permission):
@@ -44,6 +53,10 @@ def create_permission(permission: Permission):
 
 
 def edit_permission(permission: Permission):
+    if permission is not None and permission.roles is not None:
+        for role in permission.roles:
+            if hasattr(role, "permissions"):
+                del role.permissions
     return DB.update(permission)
 
 
