@@ -456,9 +456,6 @@ class Route:
         headers = {}
 
         tic = time.perf_counter()
-        if "raw" in format_:
-            route_output = jsonify(data)
-
         if "txt" in format_:
             route_output = str(data)
             if (
@@ -467,6 +464,8 @@ class Route:
                 and route_output[0] == '"'
             ):
                 route_output = route_output[1:-1]
+        elif "raw" in format_:
+            route_output = jsonify(data)
         elif "xml" in format_:
             route_output = (
                 self.returned.to_json() if "raw" in format_ else jsonify(data)
