@@ -1,4 +1,3 @@
-from sqlalchemy.ext.automap import automap_base
 from sqlalchemy import (
     Table,
     Column,
@@ -11,7 +10,7 @@ from sqlalchemy import (
     Float,
     BLOB,
 )
-from sqlalchemy.ext.declarative import declarative_base
+
 from sqlalchemy.sql import func
 from sqlalchemy.ext.declarative import declared_attr
 from sqlalchemy.orm import relationship, backref
@@ -25,17 +24,16 @@ from .models import (
     AlphaTableIdUpdateDate,
     AlphaTableUpdateDate,
 )
-
+from .tests import Test, TestChild, TestChilds
 import datetime, inspect, ast
 
-from core import core
+from core import core, DB
 
-db = core.db
 ma = core.ma
 
 
-class FilesProcess(db.Model, AlphaTableUpdateDate):
-    __bind_key__ = "main"
+class FilesProcess(DB.Model, AlphaTableUpdateDate):
+    __bind_key__ = "MAIN"
     __tablename__ = "files_process"
     ensure = True
 
@@ -48,8 +46,8 @@ class FilesProcess(db.Model, AlphaTableUpdateDate):
     error = AlphaColumn(Integer)
 
 
-class Processes(db.Model, AlphaTableIdUpdateDate):
-    __bind_key__ = "main"
+class Processes(DB.Model, AlphaTableIdUpdateDate):
+    __bind_key__ = "MAIN"
     __tablename__ = "processes"
 
     uuid = AlphaColumn(String(36))
@@ -62,19 +60,25 @@ class Processes(db.Model, AlphaTableIdUpdateDate):
     )
 
 
-class Logs(db.Model, AlphaTableIdUpdateDate):
-    __bind_key__ = "main"
+class Logs(DB.Model, AlphaTableId):
+    __bind_key__ = "MAIN"
     __tablename__ = "logs"
 
-    level = AlphaColumn(String(6), primary_key=True)
+    update_date = AlphaColumn(
+        DateTime,
+        default=datetime.datetime.now,
+        onupdate=datetime.datetime.now,
+        primary_key=True,
+    )
+    level = AlphaColumn(String(10), primary_key=True)
     type_ = AlphaColumn(String(30), primary_key=True)
     origin = AlphaColumn(String(30), primary_key=True)
-    message = AlphaColumn(Text, primary_key=True)
+    message = AlphaColumn(Text)
     stack = AlphaColumn(Text)
 
 
-class Tests(db.Model, AlphaTableIdUpdateDate):
-    __bind_key__ = "main"
+class Tests(DB.Model, AlphaTableIdUpdateDate):
+    __bind_key__ = "MAIN"
     __tablename__ = "tests"
 
     category = AlphaColumn(String(50), primary_key=True)
@@ -87,8 +91,8 @@ class Tests(db.Model, AlphaTableIdUpdateDate):
     elapsed = AlphaColumn(Float)
 
 
-class Request(db.Model, AlphaTable):
-    __bind_key__ = "main"
+class Request(DB.Model, AlphaTable):
+    __bind_key__ = "MAIN"
     __tablename__ = "request"
 
     index = AlphaColumn(Integer, primary_key=True, autoincrement=True)
@@ -107,39 +111,15 @@ class Request(db.Model, AlphaTable):
     mimetype = AlphaColumn(String(30))
 
 
-class NewsLetter(db.Model, AlphaTableIdUpdateDate):
-    __bind_key__ = "main"
+class NewsLetter(DB.Model, AlphaTableIdUpdateDate):
+    __bind_key__ = "MAIN"
     __tablename__ = "newsletter"
     name = AlphaColumn(String(100), primary_key=True)
     mail = AlphaColumn(String(50), primary_key=True)
 
 
-class Test(db.Model, AlphaTableIdUpdateDate):
-    __bind_key__ = "main"
-    __tablename__ = "test"
-
-    id = AlphaColumn(Integer, autoincrement=True)
-
-    name_ = AlphaColumn(String(30), primary_key=True)
-    text_ = AlphaColumn(String(300))
-    number_ = AlphaColumn(Integer)
-    date_ = AlphaColumn(DateTime)
-
-    __table_args__ = (db.UniqueConstraint("name_", name="test_name"),)
-
-
-class Log(db.Model, AlphaTableIdUpdateDate):
-    __bind_key__ = "main"
-    __tablename__ = "log"
-
-    type = AlphaColumn(String(30), primary_key=True)
-    origin = AlphaColumn(String(30), primary_key=True)
-    message = AlphaColumn(Text, primary_key=True)
-    stack = AlphaColumn(Text)
-
-
-class ProcesseLog(db.Model, AlphaTableIdUpdateDate):
-    __bind_key__ = "main"
+class ProcesseLog(DB.Model, AlphaTableIdUpdateDate):
+    __bind_key__ = "MAIN"
     __tablename__ = "process_log"
 
     uuid = AlphaColumn(String(36))
@@ -148,8 +128,8 @@ class ProcesseLog(db.Model, AlphaTableIdUpdateDate):
     status = AlphaColumn(String(5))
 
 
-class MailHistory(db.Model, AlphaTableIdUpdateDate):
-    __bind_key__ = "main"
+class MailHistory(DB.Model, AlphaTableIdUpdateDate):
+    __bind_key__ = "MAIN"
     __tablename__ = "mail_history"
 
     uuid = AlphaColumn(String(50))
@@ -159,8 +139,8 @@ class MailHistory(db.Model, AlphaTableIdUpdateDate):
     date = AlphaColumn(DateTime)
 
 
-class MailBlacklist(db.Model, AlphaTableId):
-    __bind_key__ = "main"
+class MailBlacklist(DB.Model, AlphaTableId):
+    __bind_key__ = "MAIN"
     __tablename__ = "mail_blacklist"
     __table_args__ = (
         UniqueConstraint("mail", "mail_type", name="unique_component_commit"),
@@ -170,45 +150,28 @@ class MailBlacklist(db.Model, AlphaTableId):
     mail_type = AlphaColumn(String(20), primary_key=True)
 
 
-class Requests(db.Model, AlphaTableIdUpdateDate):
-    __bind_key__ = "main"
-    __tablename__ = "requests"
-
-    uuid = AlphaColumn(String(100))
-    process = AlphaColumn(Integer, primary_key=True)
-    message = AlphaColumn(Text, primary_key=True)
-    message_type = AlphaColumn(String(20))
-    lifetime = AlphaColumn(Integer)
-    creation_date = AlphaColumn(DateTime, default=datetime.datetime.now)
-
-
-class Answers(db.Model, AlphaTableIdUpdateDate):
-    __bind_key__ = "main"
-    __tablename__ = "answers"
-
-    uuid = AlphaColumn(String(100))
-    process = AlphaColumn(Integer, primary_key=True)
-    message = AlphaColumn(Text, primary_key=True)
-    message_type = AlphaColumn(String(20))
-    lifetime = AlphaColumn(Integer)
-    creation_date = AlphaColumn(DateTime, default=datetime.datetime.now)
-
-
-class Constants(db.Model, AlphaTableUpdateDate):
+class Constants(DB.Model, AlphaTableUpdateDate):
     __tablename__ = "constants"
-    __bind_key__ = "main"
-
-    __table_args__ = (UniqueConstraint("name", name="constant_name"),)
+    __bind_key__ = "MAIN"
 
     name = AlphaColumn(String(30), primary_key=True)
+    type = AlphaColumn(String(10))
     value = AlphaColumn(String(100))
 
 
-class Parameters(db.Model, AlphaTableUpdateDate):
+class Parameters(DB.Model, AlphaTableUpdateDate):
     __tablename__ = "parameters"
-    __bind_key__ = "main"
-
-    __table_args__ = (UniqueConstraint("name", name="parameter_name"),)
+    __bind_key__ = "MAIN"
 
     name = AlphaColumn(String(30), primary_key=True)
     value = AlphaColumn(Text)
+
+
+class Configs(DB.Model, AlphaTableUpdateDate):
+    __tablename__ = "configs"
+    __bind_key__ = "MAIN"
+
+    name = AlphaColumn(String(30), primary_key=True)
+    type = AlphaColumn(String(10))
+    value = AlphaColumn(Text)
+
