@@ -51,6 +51,7 @@ def default_return(
     default=None,
     columns: dict = None,
     page: int = None,
+    per_page: int = None,
     full_count: int = None,
     first: bool = False,
     pagination_mode: str = "raw",
@@ -75,7 +76,7 @@ def default_return(
 
     if first and type(results) == dict and len(results) == 0:
         return None
-    if page is not None and pagination_mode == "raw":
+    if page is not None and per_page is not None and pagination_mode == "raw":
         return (results, full_count)
     return results
 
@@ -618,7 +619,10 @@ class AlphaDatabase(AlphaDatabaseCore):
             results.append(columns)
 
         if not unique:
-            rows = [Row(x) for x in results]
+            if dataclass is None:
+                rows = [Row(x) for x in results]
+            else:
+                rows = [dataclass(**x) for x in results]
         else:
             rows = [
                 value[0] if not hasattr(value, "keys") else list(value.values())[0]
@@ -917,7 +921,7 @@ class AlphaDatabase(AlphaDatabaseCore):
         relationship=True,
         disabled_relationships: typing.List[str] = None,
         page: int = None,
-        per_page: int = 100,
+        per_page: int = None,
         offset: int = None,
         dataclass=None,
         default=None,
@@ -1022,7 +1026,7 @@ class AlphaDatabase(AlphaDatabaseCore):
         relationship=True,
         disabled_relationships: typing.List[str] = None,
         page: int = None,
-        per_page: int = 100,
+        per_page: int = None,
         offset: int = None,
         dataclass=None,
         default=None,
@@ -1030,8 +1034,8 @@ class AlphaDatabase(AlphaDatabaseCore):
         distinct=None,
         group_by=None,
     ):
-        if page is not None and per_page is None:
-            per_page = 100
+        if per_page is not None and page is None:
+            page = 0
         if distinct is not None:
             query = (
                 query.distinct(distinct)
@@ -1059,7 +1063,7 @@ class AlphaDatabase(AlphaDatabaseCore):
         if first and limit is None:
             limit = 1
 
-        if page is not None:
+        if page is not None and per_page is not None:
             self.full_count = query.count()
             query = apply_order_by(query, order_by, order_by_direction, model)
             query = query.limit(per_page).offset(page * per_page)
@@ -1078,6 +1082,7 @@ class AlphaDatabase(AlphaDatabaseCore):
                     default=default,
                     columns=columns,
                     page=page,
+                    per_page=per_page,
                     full_count=self.full_count,
                     first=first,
                     pagination_mode=self.pagination_mode,
@@ -1105,6 +1110,7 @@ class AlphaDatabase(AlphaDatabaseCore):
                 default=default,
                 columns=columns,
                 page=page,
+                per_page=per_page,
                 full_count=self.full_count,
                 first=first,
                 pagination_mode=self.pagination_mode,
@@ -1149,6 +1155,7 @@ class AlphaDatabase(AlphaDatabaseCore):
                         default=default,
                         columns=columns,
                         page=page,
+                        per_page=per_page,
                         full_count=self.full_count,
                         first=first,
                         pagination_mode=self.pagination_mode,
@@ -1159,6 +1166,7 @@ class AlphaDatabase(AlphaDatabaseCore):
                         default=default,
                         columns=columns,
                         page=page,
+                        per_page=per_page,
                         full_count=self.full_count,
                         first=first,
                         pagination_mode=self.pagination_mode,
@@ -1176,6 +1184,7 @@ class AlphaDatabase(AlphaDatabaseCore):
                         default=default,
                         columns=columns,
                         page=page,
+                        per_page=per_page,
                         full_count=self.full_count,
                         first=first,
                         pagination_mode=self.pagination_mode,
@@ -1190,6 +1199,7 @@ class AlphaDatabase(AlphaDatabaseCore):
                         default=default,
                         columns=columns,
                         page=page,
+                        per_page=per_page,
                         full_count=self.full_count,
                         first=first,
                         pagination_mode=self.pagination_mode,
@@ -1206,6 +1216,7 @@ class AlphaDatabase(AlphaDatabaseCore):
                     default=default,
                     columns=columns,
                     page=page,
+                    per_page=per_page,
                     full_count=self.full_count,
                     first=first,
                     pagination_mode=self.pagination_mode,
@@ -1225,6 +1236,7 @@ class AlphaDatabase(AlphaDatabaseCore):
             default=default,
             columns=columns,
             page=page,
+            per_page=per_page,
             full_count=self.full_count,
             first=first,
             pagination_mode=self.pagination_mode,
