@@ -1,14 +1,19 @@
+import dataclasses
 import enum, inspect, operator, re
 from dataclasses import dataclass, field, is_dataclass, _MISSING_TYPE
 from collections import OrderedDict
 
-from typing import Dict, List
+from typing import Dict, Iterable, List, Optional
 from typing_extensions import Annotated
 
 from ..logger import AlphaLogger
 from ...libs import py_lib, json_lib, string_lib
 
 from ._exception import AlphaException
+
+FORCE_AUTO_MAP = False
+
+
 class AlphaEnum(enum.Enum):
     def __str__(self):
         return str(self.value)
@@ -67,13 +72,24 @@ class AlphaClass:
     def get_attributes(self):
         return py_lib.get_attributes(self)
 
-    def to_json(self):
-        rejected = ["_AlphaClass__piles", "init_args", "children", "log"]
-        dict_output = {
-            x: y if not hasattr(y, "to_json") or inspect.isclass(y) else y.to_json()
-            for x, y in self.get_attributes().items()
-            if not x in rejected
-        }
+    def to_json(
+        self, rejected: list = None, not_none: bool = False, not_empty: bool = False
+    ):
+        d_rejected = ["_AlphaClass__piles", "init_args", "children", "log"]
+        if rejected is not None:
+            d_rejected.extend(rejected)
+        dict_output = {}
+        for x, y in self.get_attributes().items():
+            if x in d_rejected:
+                continue
+            if not_none and y is None:
+                continue
+            is_iterable = py_lib.is_iterable(y)
+            if not_empty and y is not None and is_iterable and len(y) == 0:
+                continue
+            dict_output[x] = json_lib.jsonify_data(
+                y
+            )  # if not hasattr(y, "to_json") or inspect.isclass(y) else y.to_json()
         return dict_output
 
     def __log(self, stack, message, ex=None, out: bool = False):
@@ -378,17 +394,17 @@ class AutoMapping(AlphaClass):
 
         for field_key, score_dict in self.matchs_object_fields.items():
             best_match = get_score_dict_best_match(score_dict)
-            self.identified_object_fields[best_match] = self.object_fields[field_key]
+            if field_key in self.object_fields:
+                self.identified_object_fields[best_match] = self.object_fields[
+                    field_key
+                ]
 
     def __map_flat(self, dict_values: Dict[str, object]):
         if not self.is_identified:
             self.__identify_flat(dict_values)
 
         field_values = {}
-        for (
-            key,
-            fd,
-        ) in self.identified_object_fields.items():
+        for (key, fd,) in self.identified_object_fields.items():
             field_values[fd.name] = convert_value(dict_values[key], fd.type)
 
         for fd in self.dict_fields.values():
@@ -408,26 +424,17 @@ class AutoMapping(AlphaClass):
             self.identify(dict_values)
 
         field_values = {}
-        for (
-            key,
-            fd,
-        ) in self.identified_object_fields.items():
+        for (key, fd,) in self.identified_object_fields.items():
             field_values[fd.name] = convert_value(dict_values[key], fd.type)
 
-        for (
-            key,
-            fd,
-        ) in self.identified_dict_fields.items():
+        for (key, fd,) in self.identified_dict_fields.items():
             field_values[fd.name] = (
                 fd.type.auto_map_from_dict(dict_values=dict_values[key])
                 if dict_values[key] is not None
                 else None
             )
 
-        for (
-            key,
-            fd,
-        ) in self.identified_list_fields.items():
+        for (key, fd,) in self.identified_list_fields.items():
             sub_type = fd.type.__args__[0]
             if hasattr(sub_type, "auto_map_from_dict"):
                 field_values[fd.name] = (
@@ -443,14 +450,21 @@ class AutoMapping(AlphaClass):
                     else []
                 )
             else:
-                field_values[fd.name] = (
-                    [(sub_type(f) if f is not None else None) for f in dict_values[key]]
-                    if dict_values[key] is not None
-                    else []
-                )
+                if type(dict_values[key]) == str:
+                    field_values[fd.name] = string_lib.to_list(dict_values[key])
+                else:
+                    field_values[fd.name] = (
+                        [
+                            (sub_type(f) if f is not None else None)
+                            for f in dict_values[key]
+                        ]
+                        if dict_values[key] is not None
+                        else []
+                    )
         return field_values
 
-def convert_value_from_field(field_type, value, automap:bool=False):
+
+def convert_value_from_field(field_type, value, automap: bool = False):
     if value is None:
         return None
     if is_dataclass(field_type):
@@ -460,34 +474,120 @@ def convert_value_from_field(field_type, value, automap:bool=False):
             return field_type(value)
         except:
             return value
-        
+
+
 class AlphaDataclass(AlphaClass):
-    def compare(self, other, attrs_list: List[str], attrs_eq: Dict[str, str] = None) -> bool:
+    def get_fields_dict(self, keys: List[str] = None) -> dict:
+        dct = {}
+        # dct['_tname'] = self.__class__.__name__
+
+        for f in dataclasses.fields(self):
+            f_type = f.type
+            value = getattr(self, f.name)
+            if (
+                isinstance(f_type, type)
+                and issubclass(f_type, AlphaClass)
+                and value is not None
+            ):
+                value = value.get_fields_dict()
+            else:
+                value = value
+            if keys is not None and f.name not in keys:
+                continue
+            dct[f.name] = value
+
+        return dct
+
+    def compare(
+        self, other, attrs_list: List[str], attrs_eq: Dict[str, str] = None
+    ) -> bool:
         if not isinstance(other, self.__class__):
-            raise AlphaException(f"Cannot compare {self.__class__} object with {other.__class__} object")
-        
+            raise AlphaException(
+                description=f"Cannot compare {self.__class__} object with {other.__class__} object"
+            )
+
         [attrs_list.append(attr) for attr in (attrs_eq if attrs_eq is not None else [])]
-        
+
         compared = []
         for attr in attrs_list:
-            if hasattr(self, attr):                
+            if hasattr(self, attr):
                 self_attr, other_attr = getattr(self, attr), getattr(other, attr)
-                
-                custom_eq = attrs_eq[attr] if attrs_eq is not None and attr in attrs_eq else None
-                
-                if self_attr is None and other_attr is not None:
+
+                custom_eq = (
+                    attrs_eq[attr]
+                    if attrs_eq is not None and attr in attrs_eq
+                    else None
+                )
+
+                if (self_attr is None and other_attr is not None) or (
+                    other_attr is None and self_attr is not None
+                ):
                     compared.append(False)
                 elif self_attr is None and other_attr is None:
                     compared.append(True)
                 elif custom_eq is not None:
-                    compared.append(getattr(self_attr,custom_eq)(other_attr))
+                    compared.append(getattr(self_attr, custom_eq)(other_attr))
                 else:
-                    compared.append(getattr(self_attr,"__eq__")(other_attr))
+                    compared.append(getattr(self_attr, "__eq__")(other_attr))
             else:
-                raise AlphaException(f"{self.__class__} object has no attribute {attr}")
+                raise AlphaException(
+                    description=f"{self.__class__.__name__} object has no attribute {attr}"
+                )
 
         return all(compared)
 
+    def check_attrs_not_none(self, attrs_list: List[str]) -> Optional[bool]:
+        if attrs_list is None:
+            return
+
+        for attr in attrs_list:
+            if hasattr(self, attr):
+                self_attr = getattr(self, attr)
+                if self_attr is None:
+                    raise AlphaException(
+                        description=f"{self.__class__.__name__} '{attr}' cannot be 'None'"
+                    )
+            else:
+                raise AlphaException(
+                    description=f"{self.__class__.__name__} object has no attribute {attr}"
+                )
+
+        return True
+
+    def check_attrs_none(self, attrs_list: List[str]) -> Optional[bool]:
+        if attrs_list is None:
+            return
+
+        for attr in attrs_list:
+            if hasattr(self, attr):
+                self_attr = getattr(self, attr)
+                if self_attr is not None:
+                    raise AlphaException(
+                        description=f"{self.__class__.__name__} '{attr}' must be 'None'"
+                    )
+            else:
+                raise AlphaException(
+                    description=f"{self.__class__.__name__} object has no attribute {attr}"
+                )
+
+        return True
+
+    def replace_empty_with_none(self, attrs_list: List[str]) -> Optional[bool]:
+        if attrs_list is None:
+            return
+
+        for attr in attrs_list:
+            if hasattr(self, attr):
+                self_attr = getattr(self, attr)
+                if self_attr == "":
+                    self.__dict__[attr] = None
+            else:
+                raise AlphaException(
+                    description=f"{self.__class__.__name__} object has no attribute {attr}"
+                )
+
+        return True
+
     def update_from_auto_map_from_dict(
         self,
         dict_values: Dict[str, object],
@@ -503,6 +603,35 @@ class AlphaDataclass(AlphaClass):
             if fd is not None:
                 setattr(self, key, fd)
 
+    def flatten(self, parent: str = None):
+        output = {}
+        for key, field in self.__dataclass_fields__.items():
+            value = self.__dict__[key]
+            value_key = f"{parent}.{key}" if parent is not None else key
+
+            if value is None:
+                output[value_key] = None
+            elif isinstance(value, AlphaDataclass):
+                for k, v in value.flatten(parent=key).items():
+                    output[k] = v
+            elif type(value) == dict:
+                for k, v in value.items():
+                    output[f"{value_key}.{k}"] = v
+            elif py_lib.is_list(value):
+                output[value_key] = []
+                for el in value:
+                    if isinstance(el, AlphaDataclass):
+                        output[value_key].append(el.flatten())
+                    else:
+                        output[value_key].append(el)
+            else:
+                output[value_key] = value
+        return output
+
+    @classmethod
+    def get_fields_names(dataclass_type):
+        return [f.name for f in dataclasses.fields(dataclass_type)]
+
     @classmethod
     def auto_map_from_dict(
         dataclass_type,
@@ -511,7 +640,7 @@ class AlphaDataclass(AlphaClass):
         no_match: List[str] = [],
         flat: bool = False,
     ):
-        global DATACLASS_AUTO_MAP_MATCHS
+        global DATACLASS_AUTO_MAP_MATCHS, FORCE_AUTO_MAP
         if dict_values is None:
             return dataclass_type()
 
@@ -519,7 +648,7 @@ class AlphaDataclass(AlphaClass):
         uuid = f"{dataclass_name}({','.join(list(dict_values.keys()))})"
 
         # FIELDS
-        if not uuid in DATACLASS_AUTO_MAP_MATCHS:
+        if not uuid in DATACLASS_AUTO_MAP_MATCHS or FORCE_AUTO_MAP:
             DATACLASS_AUTO_MAP_MATCHS[uuid] = AutoMapping(
                 dataclass_type, associations=associations, no_match=no_match, flat=flat
             )
@@ -547,8 +676,18 @@ class AlphaDataclass(AlphaClass):
 
     @classmethod
     def map_from_json(dataclass_type, json_values: str, automap: bool = False):
-        dict_value = json_lib.load_json(json_values)
-        return dataclass_type.map_from_dict(dict_value, automap=automap)
+        dict_value = (
+            json_lib.load_json(json_values)
+            if type(json_values) != dict
+            else json_values
+        )
+        try:
+            obj = dataclass_type.map_from_dict(dict_value, automap=automap)
+        except Exception as ex:
+            print(f"Failed to map {dataclass_type} with: {json_values}")
+            print(ex)
+            obj = None
+        return obj
 
     @classmethod
     def map_from_dict(
@@ -556,23 +695,36 @@ class AlphaDataclass(AlphaClass):
     ):
         if automap and hasattr(dataclass_type, "auto_map_from_dict"):
             return dataclass_type.auto_map_from_dict(dict_values=dict_value)
-        
-        if not py_lib.is_subtype(type(dict_value), Dict) and not py_lib.is_subtype(type(dict_value), dict) and not type(dict_value) == dict:
+
+        if (
+            not py_lib.is_subtype(type(dict_value), Dict)
+            and not py_lib.is_subtype(type(dict_value), dict)
+            and not type(dict_value) == dict
+        ):
             return None
         if dict_value is None:
             return None
-        
+
         field_values = {}
         for key, value in dict_value.items():
             if key in dataclass_type.__dataclass_fields__:
                 field = dataclass_type.__dataclass_fields__[key]
                 field_type = field.type
-                
-                if py_lib.is_subtype(field_type, List) or py_lib.is_subtype(field_type, list):
+
+                if py_lib.is_subtype(field_type, List) or py_lib.is_subtype(
+                    field_type, list
+                ):
                     if value is not None:
-                        field_values[key] = [convert_value_from_field(py_lib.get_subtype(field_type), v, automap=automap) for v in value]
+                        field_values[key] = [
+                            convert_value_from_field(
+                                py_lib.get_subtype(field_type), v, automap=automap
+                            )
+                            for v in value
+                        ]
                     else:
                         field_values[key] = []
                 else:
-                    field_values[key] = convert_value_from_field(field_type, value, automap=automap)
+                    field_values[key] = convert_value_from_field(
+                        field_type, value, automap=automap
+                    )
         return dataclass_type(**field_values)
