@@ -1,5 +1,5 @@
 # coding: utf8
-# 
+#
 
 import os, requests, webbrowser, selenium, time
 from pystray import Icon, Menu, MenuItem
@@ -31,10 +31,11 @@ icon.visible = True
 icon.run(setup=callback)
 """
 
-#rep = stitch.Stitch.getWebsites()
+# rep = stitch.Stitch.getWebsites()
 
 state = True
 
+
 def on_clicked(icon, item):
     global state
     state = not item.checked
@@ -42,19 +43,18 @@ def on_clicked(icon, item):
     if item.checked:
         api.start()
 
+
 def exitAlpha():
     icon.stop()
-    
+
+
 global icon
-icon        = Icon('test name')
-icon.icon   = Image.open("src/alpha.png")
-icon.menu   = Menu(
-        MenuItem('Alpha',None),
-        MenuItem(
-            'Running',
-            on_clicked,
-            checked=lambda item: state),
-        MenuItem('Exit',exitAlpha),
-    )
-    
-icon.run()
\ No newline at end of file
+icon = Icon("test name")
+icon.icon = Image.open("src/alpha.png")
+icon.menu = Menu(
+    MenuItem("Alpha", None),
+    MenuItem("Running", on_clicked, checked=lambda item: state),
+    MenuItem("Exit", exitAlpha),
+)
+
+icon.run()
